/* BdfServer - Copyright (c) 2015-2020 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.tools.ui.options;

import fr.exemole.bdfserver.api.ui.options.InputOption;


/**
 *
 * @author Vincent Calame
 */
public class InputOptionBuilder {

    private String inputType = InputOption.INPUT_TEXT;
    private String widthType = InputOption.WIDTH_LARGE;
    private int rows = 1;

    public InputOptionBuilder() {

    }

    public InputOptionBuilder setInputType(String inputType) {
        this.inputType = UiOptionsUtils.checkInputType(inputType);
        return this;
    }

    public InputOptionBuilder setWidthType(String widthType) {
        this.widthType = UiOptionsUtils.checkWidthType(widthType);
        return this;
    }

    public InputOptionBuilder setRows(int rows) {
        if (rows <= 0) {
            throw new IllegalArgumentException("rows <= 0");
        }
        this.rows = rows;
        return this;
    }

    public InputOption toInputOption() {
        return new InternalInputOption(inputType, widthType, rows);
    }

    public static InputOptionBuilder derive(InputOption inputOption) {
        InputOptionBuilder builder = new InputOptionBuilder();
        builder.setInputType(inputOption.getInputType());
        builder.setWidthType(inputOption.getWidthType());
        builder.setRows(inputOption.getRows());
        return builder;
    }

    public static InputOption build(String inputType, String widthType, int rows) {
        InputOptionBuilder builder = new InputOptionBuilder();
        builder.setInputType(inputType);
        builder.setWidthType(widthType);
        builder.setRows(rows);
        return builder.toInputOption();
    }

    public static InputOptionBuilder init() {
        return new InputOptionBuilder();
    }


    private static class InternalInputOption implements InputOption {

        private final String inputType;
        private final String widthType;
        private final int rows;

        public InternalInputOption(String inputType, String widthType, int rows) {
            this.inputType = inputType;
            this.widthType = widthType;
            this.rows = rows;
        }

        @Override
        public String getInputType() {
            return inputType;
        }

        @Override
        public String getWidthType() {
            return widthType;
        }

        @Override
        public int getRows() {
            return rows;
        }

    }

}
