/* BdfServer_JsonProducers - Copyright (c) 2013-2022 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.jsonproducers.importation;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.instruction.BdfCommandResult;
import fr.exemole.bdfserver.api.instruction.BdfInstructionConstants;
import fr.exemole.bdfserver.api.instruction.OutputParameters;
import fr.exemole.bdfserver.api.interaction.domains.ImportationDomain;
import fr.exemole.bdfserver.jsonproducers.ResultJsonProducer;
import java.util.List;
import net.fichotheque.corpus.fiche.FicheBlock;
import net.fichotheque.importation.ParseResult;
import net.mapeadores.util.json.JsonProducer;
import net.mapeadores.util.localisation.MessageLocalisation;
import net.mapeadores.util.logging.ErrorMessageException;


/**
 *
 * @author Vincent Calame
 */
public final class ImportationJsonProducerFactory {

    private ImportationJsonProducerFactory() {
    }

    public static JsonProducer getJsonProducer(OutputParameters parameters) throws ErrorMessageException {
        String json = parameters.getOutput();
        BdfCommandResult bdfCommandResult = parameters.getBdfCommandResult();
        BdfServer bdfServer = parameters.getBdfServer();
        MessageLocalisation messageLocalisation = parameters.getMessageLocalisation();
        ResultJsonProducer jsonProducer = new ResultJsonProducer(bdfCommandResult, messageLocalisation);
        switch (json) {
            case ImportationDomain.PARSERESULT_JSON: {
                if (bdfCommandResult != null) {
                    ParseResult parseResult = (ParseResult) bdfCommandResult.getResultObject(BdfInstructionConstants.PARSERESULT_OBJ);
                    if (parseResult != null) {
                        jsonProducer.add(new ParseResultJsonProperty(bdfServer, parseResult));
                        return jsonProducer;
                    }
                }
                return null;
            }
            case ImportationDomain.FICHEBLOCKSYNTAX_JSON: {
                if (bdfCommandResult != null) {
                    List<FicheBlock> ficheBlockList = (List<FicheBlock>) bdfCommandResult.getResultObject(BdfInstructionConstants.FICHEBLOCKLIST_OBJ);
                    if (ficheBlockList != null) {
                        jsonProducer.add(new FicheblockSyntaxJsonProperty(ficheBlockList));
                        return jsonProducer;
                    }
                }
                return null;
            }
            default:
                return null;
        }
    }

}
