/* BdfServer_Multi - Copyright (c) 2022 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.multi.htmlproducers;

import fr.exemole.bdfserver.api.users.BdfUser;
import fr.exemole.bdfserver.html.jslib.AdminJsLibs;
import fr.exemole.bdfserver.json.BdfUserJson;
import fr.exemole.bdfserver.multi.api.Multi;
import fr.exemole.bdfserver.multi.tools.CrossInfo;
import fr.exemole.bdfserver.tools.storage.StorageUtils;
import net.mapeadores.util.html.HA;
import net.mapeadores.util.html.JsObject;


/**
 *
 * @author Vincent Calame
 */
public class IndexHtmlProducer extends MultiHtmlProducer {

    private final CrossInfo crossInfo;

    public IndexHtmlProducer(Multi multi, CrossInfo crossInfo) {
        super(multi, crossInfo.getBdfUser().getLangPreference());
        this.crossInfo = crossInfo;
        addJsLib(AdminJsLibs.INDEX);
        addThemeCss("index.css");
    }

    @Override
    public void printHtml() {
        BdfUser bdfUser = crossInfo.getBdfUser();
        JsObject bdfUserJsObject = new JsObject();
        BdfUserJson.populate(bdfUserJsObject, bdfUser);
        boolean withLogo = multi.getWebappsResourceStorages().containsResource(StorageUtils.LOGO);
        String title = getTitle(multi.getServletContextName());
        JsObject args = JsObject.init()
                .put("sphereName", crossInfo.getSphereKey().getSubsetName())
                .put("title", title)
                .put("withLogo", withLogo)
                .put("bdfUser", bdfUserJsObject);
        start(title);
        this
                .SCRIPT()
                .__jsObject("Index.ARGS", args)
                ._SCRIPT();
        this
                .DIV(HA.id("layout"))._DIV();
        end();
    }

}
