/* global BDF,TableExport,Overlay,$$ */

TableExport.List = {};

TableExport.List.init = function (callback) {
    BDF.Ajax.loadTableExportArray(function (tableExportArray) {
        tableExportArray = TableExport.initArray(tableExportArray);
        let $listBody = $$("listpane_body");
        $listBody.html(BDF.render("tableexport:list/tableexport", tableExportArray));
        TableExport.List.initActions();
        BDF.Deploy.init($listBody);
        if (callback) {
            callback();
        }
    });
};

TableExport.List.initActions = function () {
    $$("listpane_button_newtableexport").click(TableExport.Overlay.showTableExportCreationForm);
    var $body = $$("listpane_body");
    BDF.onClick($body, {action: "metadata"}, function () {
        if (!BDF.confirmUnload()) {
            return false;
        }
        let name = BDF.Pane.getEntryName(this);
        BDF.Pane.loadOrDestock(name, function () {
            TableExport.MetadataForm.load(name);
        });
    });
    BDF.onClick($body, {action: "tableexportremove"}, function () {
        TableExport.Overlay.showTableExportRemoveConfirm(BDF.Pane.getEntryName(this));
    });
    BDF.onClick($body, {action: "newcorpuscontent"}, function () {
        TableExport.Overlay.showCorpusContentCreationForm(BDF.Pane.getEntryName(this));
    });
    BDF.onClick($body, {action: "newthesauruscontent"}, function () {
        TableExport.Overlay.showThesaurusContentCreationForm(BDF.Pane.getEntryName(this));
    });
    BDF.onClick($body, {action: "tableexportcopy"}, function () {
        TableExport.Overlay.showTableExportCopyForm(BDF.Pane.getEntryName(this));
    });
    BDF.onClick($body, {action: "load-main"}, function () {
        if (!BDF.confirmUnload()) {
            return false;
        }
        let $reference = BDF.$parents($(this), {role: "content-reference"});
        BDF.Pane.loadOrDestock($reference.data("contentKey"), function () {
            _loadContent($reference, false);
        });
        return false;
    });
    BDF.onClick($body, {action: "load-stock"}, function () {
        let $reference = BDF.$parents($(this), {role: "content-reference"});
        let state = BDF.Pane.State.build();
        if (state.isLoaded($reference.data("contentKey"))) {
            return;
        }
        _loadContent($reference, true);
    });

    
    function _loadContent($reference, isInStock) {
        let overlayId = BDF.startRunningOverlay();
        BDF.Ajax.loadTableExportContent($reference.data("tableExportName"), $reference.data("contentPath"), function (tableExportContent) {
            TableExport.ContentForm.load(tableExportContent, isInStock);
            Overlay.end(overlayId);
        });
    }
    
};

TableExport.List.updateTableExport = function (newTableExportObj) {
    var $currentTableExport = BDF.$({role: "entry", name: newTableExportObj.name});
    BDF.$($currentTableExport, {role: "entry-title"}).html(newTableExportObj.title);
    BDF.Pane.updateStateClass($currentTableExport, "tableexport-state-" + newTableExportObj.state);
    var $contentUl = BDF.$($currentTableExport, {role: "content-list"});
    BDF.Pane.updateContentList("tableexport", $contentUl, newTableExportObj.contentArray);
};

/**
 * Retourne l'ensemble des contenus existants d'une exportation
 * sous la forme d'un objet Map avec les noms des contenus comme clé (qui ont la valeur true)
 */
TableExport.List.getExistingSubsetMap = function (tableExportName) {
    var result = new Map();
    var $tableExport = BDF.Pane.getEntry(tableExportName);
    BDF.$($tableExport, {role: "content-reference"}).each(function (index, element) {
        let contentPath = $(element).data("contentPath");
        let subsetKeyObj = TableExport.parseSubsetKey(contentPath);
        result.set(subsetKeyObj.subsetKey, true);
    });
    return result;
};
