/* FichothequeLib_Tools - Copyright (c) 2011-2022 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.fichotheque.tools.extraction;

import net.fichotheque.extraction.LinkAnalyser;
import net.fichotheque.extraction.ModeResolver;
import net.fichotheque.extraction.def.AddendaExtractDef;
import net.fichotheque.extraction.def.AlbumExtractDef;
import net.fichotheque.extraction.def.CorpusExtractDef;
import net.fichotheque.extraction.def.ThesaurusExtractDef;
import net.fichotheque.extraction.run.AddendaExtractor;
import net.fichotheque.extraction.run.AlbumExtractor;
import net.fichotheque.extraction.run.CorpusExtractor;
import net.fichotheque.extraction.run.ExtractorProvider;
import net.fichotheque.extraction.run.ThesaurusExtractor;


/**
 *
 * @author Vincent Calame
 */
public final class ExtractionContextUtils {

    public final static ExtractorProvider DEFAULT_EXTRACTORPROVIDER = new DefaultExtractorProvider();
    public final static LinkAnalyser DEFAULT_LINKANALYSER = new DefaultLinkAnalyser();
    public final static ModeResolver DEFAULT_MODERESOLVER = new DefaultModeResolver();


    private ExtractionContextUtils() {
    }


    private static class DefaultLinkAnalyser implements LinkAnalyser {

        private DefaultLinkAnalyser() {
        }

        @Override
        public boolean isExternalLink(String href) {
            if (href == null) {
                return false;
            }
            return (href.indexOf("://") > 0);
        }

    }


    private static class DefaultExtractorProvider implements ExtractorProvider {

        private DefaultExtractorProvider() {
        }

        @Override
        public AddendaExtractor getAddendaExtractor(AddendaExtractDef addendaExtractDef) {
            return new AddendaExtractorImpl(addendaExtractDef);
        }

        @Override
        public AlbumExtractor getAlbumExtractor(AlbumExtractDef albumExtractDef) {
            return new AlbumExtractorImpl(albumExtractDef);
        }

        @Override
        public CorpusExtractor getCorpusExtractor(CorpusExtractDef corpusExtractDef) {
            return new CorpusExtractorImpl(corpusExtractDef);
        }

        @Override
        public ThesaurusExtractor getThesaurusExtractor(ThesaurusExtractDef thesaurusExtractDef) {
            return new ThesaurusExtractorImpl(thesaurusExtractDef);
        }

    }


    private static class DefaultModeResolver implements ModeResolver {


        private DefaultModeResolver() {

        }

        @Override
        public String toCData(String mode, String sValue) {
            switch (mode) {
                case "ficheblock":
                    return FicheblockMode.resolve(sValue);
                default:
                    return "";
            }
        }

    }


}
