/* FichothequeLib_Tools - Copyright (c) 2010-2022 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.fichotheque.tools.extraction.builders;

import net.fichotheque.utils.FilterUnitUtils;
import java.util.List;
import net.fichotheque.corpus.metadata.FieldKey;
import net.fichotheque.extraction.def.FicheFilter;
import net.fichotheque.extraction.def.TagNameInfo;
import net.fichotheque.extraction.filterunit.CorpsdeficheFilterUnit;
import net.fichotheque.extraction.filterunit.FieldKeyFilterUnit;
import net.fichotheque.extraction.filterunit.FieldNamePrefixFilterUnit;
import net.fichotheque.extraction.filterunit.FilterUnit;


/**
 *
 * @author Vincent Calame
 */
public class FicheFilterBuilder {

    private TagNameInfo tagNameInfo = TagNameInfo.DEFAULT;
    private FilterUnit[] filterUnitArray = null;
    private boolean withCorpsdefiche = false;

    public FicheFilterBuilder() {
    }

    public FicheFilterBuilder setTagNameInfo(TagNameInfo tagNameInfo) {
        this.tagNameInfo = tagNameInfo;
        return this;
    }

    public FicheFilterBuilder updateFilterUnitList(List<FilterUnit> filterUnitList) {
        if (filterUnitList == null) {
            filterUnitArray = null;
        }
        filterUnitArray = filterUnitList.toArray(new FilterUnit[filterUnitList.size()]);
        for (FilterUnit filterUnit : filterUnitArray) {
            if (filterUnit instanceof CorpsdeficheFilterUnit) {
                withCorpsdefiche = true;
            } else if (filterUnit instanceof FieldKeyFilterUnit) {
                checkWithCorpsdefiche(((FieldKeyFilterUnit) filterUnit).getFieldKey().getCategory());
            } else if (filterUnit instanceof FieldNamePrefixFilterUnit) {
                checkWithCorpsdefiche(((FieldNamePrefixFilterUnit) filterUnit).getCategory());
            }
        }
        return this;
    }

    private void checkWithCorpsdefiche(short category) {
        switch (category) {
            case FieldKey.SECTION_CATEGORY:
                withCorpsdefiche = true;
                break;
        }
    }

    public FicheFilter toFicheFilter() {
        List<FilterUnit> filterUnitList;
        if (filterUnitArray == null) {
            filterUnitList = FilterUnitUtils.EMPTY_FILTERUNITLIST;
        } else {
            filterUnitList = FilterUnitUtils.wrap(filterUnitArray);
        }
        return new InternalFicheFilter(tagNameInfo, filterUnitList, withCorpsdefiche);
    }

    public static FicheFilterBuilder init() {
        return new FicheFilterBuilder();
    }


    public static FicheFilter fromFilterUnitList(List<FilterUnit> filterUnitList) {
        return FicheFilterBuilder.init()
                .updateFilterUnitList(filterUnitList)
                .toFicheFilter();
    }


    private static class InternalFicheFilter implements FicheFilter {

        private final TagNameInfo tagNameInfo;
        private final List<FilterUnit> filterUnitList;
        private final boolean withCorpsdefiche;


        private InternalFicheFilter(TagNameInfo tagNameInfo, List<FilterUnit> filterUnitList, boolean withCorpsdefiche) {
            this.tagNameInfo = tagNameInfo;
            this.filterUnitList = filterUnitList;
            this.withCorpsdefiche = withCorpsdefiche;
        }

        @Override
        public TagNameInfo getTagNameInfo() {
            return tagNameInfo;
        }

        @Override
        public boolean isWithCorpsdefiche() {
            return withCorpsdefiche;
        }

        @Override
        public List<FilterUnit> getFilterUnitList() {
            return filterUnitList;
        }

    }


}
