/* FichothequeLib_Tools - Copyright (c) 2012-2019 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.fichotheque.tools.format.tokenizers;

import java.util.AbstractList;
import java.util.function.BiFunction;
import java.util.function.Predicate;
import net.fichotheque.SubsetItem;
import net.fichotheque.format.FormatSource;
import net.fichotheque.format.Tokenizer;
import net.fichotheque.format.Tokens;
import net.fichotheque.format.formatters.ExtractionFormatter;
import net.fichotheque.pointeurs.SubsetItemPointeur;


/**
 *
 * @author Vincent Calame
 */
public class ExtractionTokenizer implements Tokenizer {

    private final ExtractionFormatter extractionFormatter;

    public ExtractionTokenizer(ExtractionFormatter extractionFormatter) {
        super();
        this.extractionFormatter = extractionFormatter;
    }

    @Override
    public Tokens tokenize(FormatSource formatSource) {
        String extractionString = null;
        BiFunction<SubsetItem, Predicate<SubsetItem>, String> extractionFunction = formatSource.getExtractionFunction();
        SubsetItemPointeur pointeur = formatSource.getSubsetItemPointeur();
        SubsetItem currentSubsetItem = pointeur.getCurrentSubsetItem();
        if (currentSubsetItem != null) {
            String objectName = this.getClass().getName();
            Object currentExtraction = pointeur.getCurrentObject(objectName);
            if ((currentExtraction != null) && (currentExtraction instanceof String)) {
                extractionString = (String) currentExtraction;
            } else {
                extractionString = extractionFunction.apply(currentSubsetItem, formatSource.getGlobalPredicate());
                pointeur.putCurrentObject(objectName, extractionString);
            }
        }
        return new InternalTokens(extractionString, extractionFormatter, formatSource);
    }


    private static class InternalTokens extends AbstractList<String> implements Tokens {

        private final String extractionString;
        private final ExtractionFormatter extractionFormatter;
        private final FormatSource formatSource;

        private InternalTokens(String extractionString, ExtractionFormatter extractionFormatter, FormatSource formatSource) {
            this.extractionString = extractionString;
            this.extractionFormatter = extractionFormatter;
            this.formatSource = formatSource;
        }

        @Override
        public int size() {
            if (extractionString == null) {
                return 0;
            } else {
                return 1;
            }
        }

        @Override
        public String get(int i) {
            if (extractionString == null) {
                throw new IndexOutOfBoundsException("size = 0");
            }
            return extractionFormatter.formatExtraction(extractionString, formatSource);
        }

    }

}
