/* UtilLib - Copyright (c) 2013-2017 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.mapeadores.util.logging;

import java.util.ArrayList;
import java.util.List;
import net.mapeadores.util.localisation.Message;


/**
 *
 * @author Vincent Calame
 */
public class MessageLogBuilder implements MultiMessageHandler {

    private final CategorizedMessageBuffer currentBuffer = new CategorizedMessageBuffer();
    private String currentURI = null;
    private final List<InternalLogGroup> groupList = new ArrayList<InternalLogGroup>();

    public MessageLogBuilder() {
    }

    @Override
    public void setCurrentURI(String uri) {
        if (currentBuffer.isEmpty()) {
            currentURI = uri;
        } else {
            boolean flush = false;
            if (uri == null) {
                if (currentURI != null) {
                    flush = true;
                }
            } else if (currentURI == null) {
                flush = true;
            } else {
                flush = !uri.equals(currentURI);
            }
            if (flush) {
                flushGroup();
                currentURI = uri;
            }
        }
    }

    @Override
    public void addMessage(String category, Message message) {
        currentBuffer.add(category, message);
    }

    private void flushGroup() {
        if (!currentBuffer.isEmpty()) {
            groupList.add(new InternalLogGroup(currentURI, currentBuffer.toEntryList()));
            currentBuffer.clear();
        }
    }

    public MessageLog toMessageLog() {
        flushGroup();
        List<MessageLog.LogGroup> finalList = LogUtils.wrap(groupList.toArray(new MessageLog.LogGroup[groupList.size()]));
        return new InternalMessageLog(finalList);
    }


    private static class InternalLogGroup implements MessageLog.LogGroup {

        private final String processURI;
        private final List<CategorizedMessageEntry> messageList;

        private InternalLogGroup(String processURI, List<CategorizedMessageEntry> messageList) {
            this.processURI = processURI;
            this.messageList = messageList;
        }

        @Override
        public String getURI() {
            return processURI;
        }

        @Override
        public List<CategorizedMessageEntry> getEntryList() {
            return messageList;
        }

    }


    private static class InternalMessageLog implements MessageLog {

        private final List<MessageLog.LogGroup> list;

        private InternalMessageLog(List<MessageLog.LogGroup> list) {
            this.list = list;
        }

        @Override
        public List<LogGroup> getLogGroupList() {
            return list;
        }

    }

}
